@@ -1,6 +1,18 @@
+import itertools
 import time
 from functools import partial
-from typing import Any, Callable, Dict, Generator, List, Optional, Set, Tuple, Union
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    Generator,
+    List,
+    Optional,
+    Set,
+    Tuple,
+    Union,
+    cast,
+)
 from urllib.parse import urlparse
 
 import click
@@ -123,12 +135,14 @@ def render_limits(
                 "blueprint"
                 if blueprint
                 and limit in limiter.limit_manager.blueprint_limits(app, blueprint)
-                else "route"
-                if limit
-                in limiter.limit_manager.decorated_limits(
-                    get_qualified_name(view_func) if view_func else ""
+                else (
+                    "route"
+                    if limit
+                    in limiter.limit_manager.decorated_limits(
+                        get_qualified_name(view_func) if view_func else ""
+                    )
+                    else "default"
                 )
-                else "default"
             )
         else:
             source = "default"
@@ -177,7 +191,7 @@ def get_filtered_endpoint(
             filter_endpoint, _ = adapter.match(
                 parsed.path, method=method, query_args=parsed.query
             )
-            return filter_endpoint
+            return cast(str, filter_endpoint)
         except NotFound:
             console.print(
                 f"[error]Error: {path} could not be matched to an endpoint[/error]"
@@ -197,7 +211,7 @@ def cli() -> None:
 
 
 @cli.command(help="View the extension configuration")
-@with_appcontext  # type: ignore
+@with_appcontext
 def config() -> None:
     with current_app.test_request_context():
         console = Console(theme=limiter_theme)
@@ -239,6 +253,21 @@ def config() -> None:
                         ]
                     ),
                 )
+                extension_details.add_row(
+                    None,
+                    ConfigVars.APPLICATION_LIMITS_PER_METHOD,
+                    Pretty(limiter._application_limits_per_method),
+                )
+                extension_details.add_row(
+                    None,
+                    ConfigVars.APPLICATION_LIMITS_EXEMPT_WHEN,
+                    render_func(limiter._application_limits_exempt_when),
+                )
+                extension_details.add_row(
+                    None,
+                    ConfigVars.APPLICATION_LIMITS_DEDUCT_WHEN,
+                    render_func(limiter._application_limits_deduct_when),
+                )
                 extension_details.add_row(
                     None,
                     ConfigVars.APPLICATION_LIMITS_COST,
@@ -286,6 +315,17 @@ def config() -> None:
                     "Default Limits", ConfigVars.DEFAULT_LIMITS, Pretty([])
                 )
 
+            if limiter._meta_limits:
+                extension_details.add_row(
+                    "Meta Limits",
+                    ConfigVars.META_LIMITS,
+                    Pretty(
+                        [
+                            render_limit(limit)
+                            for limit in itertools.chain(*limiter._meta_limits)
+                        ]
+                    ),
+                )
             if limiter._headers_enabled:
                 header_configs = Tree(ConfigVars.HEADERS_ENABLED)
                 header_configs.add(ConfigVars.HEADER_RESET)
@@ -337,7 +377,7 @@ def config() -> None:
 @click.option("--method", default=None, help="HTTP Method to filter by")
 @click.option("--key", default=None, help="Test the limit")
 @click.option("--watch/--no-watch", default=False, help="Create a live dashboard")
-@with_appcontext  # type: ignore
+@with_appcontext
 def limits(
     endpoint: Optional[str] = None,
     path: Optional[str] = None,
@@ -407,6 +447,14 @@ def limits(
                     and limiter.limit_manager.application_limits
                     and not (endpoint or path)
                 ):
+                    yield render_limits(
+                        current_app,
+                        limiter,
+                        (list(itertools.chain(*limiter._meta_limits)), []),
+                        test=key,
+                        method=method,
+                        label="[gold3]Meta Limits[/gold3]",
+                    )
                     yield render_limits(
                         current_app,
                         limiter,
@@ -451,7 +499,7 @@ def limits(
 @click.option("--method", default=None, help="HTTP Method to filter by")
 @click.option("--key", default=None, required=True, help="Key to reset the limits for")
 @click.option("-y", is_flag=True, help="Skip prompt for confirmation")
-@with_appcontext  # type: ignore
+@with_appcontext
 def clear(
     key: str,
     endpoint: Optional[str] = None,
